@@ -18,7 +18,7 @@ from .log import logger
 from .solution import *
 from .repo import *
 
-
+import copy
 class Configure:
     def __init__(self):
         self.lastUpdateTime = 0
@@ -445,6 +445,21 @@ class YoC:
                         exit(-1)
                     else:
                         return {}
+                separate_app_component = []
+                if component.separate_app:        
+                    separate_app_component = copy.deepcopy(component)
+                    separate_app_component.source_files.remove("maintask.c")
+                    separate_app_component.name = 'separate_app'
+                    separate_app_component.type = 'dynamic'
+                    separate_app_component.path = os.path.join(component.path, "separate_app")
+                    separate_app_component.build_config.shldflag = '-e application_start'
+                    
+                    for i in range(len(separate_app_component.source_files)):
+                        separate_app_component.source_files[i] = separate_app_component.source_files[i].replace('separate_app/', '')
+                    separate_app_component.save_package()
+                    components.add(separate_app_component)
+                    self.components.add(separate_app_component)
+                    component.source_files = ["maintask.c"]
                 components.add(component)
                 # depends and condition
                 parent_names = [component.name, component.hw_info.board_name]
